#    Copyright 2012 OpenStack Foundation
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import testtools
from mock import Mock, MagicMock
from trove.guestagent import service


class ServiceTest(testtools.TestCase):
    def setUp(self):
        super(ServiceTest, self).setUp()

    def tearDown(self):
        super(ServiceTest, self).tearDown()

    def test_app_factory(self):
        service.API._instance_router = MagicMock()
        service.app_factory(Mock)
        self.assertEqual(1, service.API._instance_router.call_count)
